@@ -90,6 +90,7 @@ char *app_name = "wmcalc";     /* Name of app, for window management */
     01/17/01   Updated to use XLookupString to get KeySym
     11/09/00   Added Events for focus and keyboard work.
     11/01/00   File Header Added
+    21/09/01   Added global configfile by Gordon Fraser
  ****************************************************************/
 int main( int argc, char **argv ) {
   XEvent report;
@@ -107,6 +108,7 @@ int main( int argc, char **argv ) {
   int bufsize = 20;
   int chcnt = 0;
   
+
   strcpy(configfile, getenv("HOME"));  // Added to wmbutton by Casey Harkin, 3/6/99
   strcat(configfile, CONFFILENAME);    // Fixed Bug - didn't look in home directory
                                        // but startup directory
@@ -428,7 +430,7 @@ void redraw() {
   flush_expose( iconwin ); 
   XCopyArea(display, visible.pixmap, iconwin, gc, 0, 0,
 	    visible.attributes.width, visible.attributes.height, 0, 0 );
-  if ( Verbose ) printf("In Redraw()\n");	
+  //  if ( Verbose ) printf("In Redraw()\n");	
   displaystr();
 }  /***** End of function redraw() ********************************/
 
@@ -471,7 +473,6 @@ int whichButton( int x, int y ) {
  ****************************************************************/
 int whichKey (KeySym keysym) {
   extern int      Verbose;
-  extern Display  *display;
   int        func   = NO_BUTTON;
 
   if (Verbose) printf("KeySym 0x%x received, decoding...\n", (int) keysym);
